@@ -1,20 +1,16 @@
-import yaml
 import argparse
 from PIL import Image
 
-from tool.detector import TextDetector
+from transformerocr.tool.detector import TextDetector
 
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument('--img', required=True, help='foo help')
-    parser.add_argument('--config', default='config/vgg-transformer.yml', help='foo help')
+    parser.add_argument('--config', required=True, help='foo help')
 
     args = parser.parse_args()
 
-    with open(args.config, 'r') as stream:
-        config = yaml.safe_load(stream)
-    
-    detector = TextDetector(config)
+    detector = TextDetector(args.config)
 
     img = Image.open(args.img)
     s = detector.predict(img)
