@@ -4,8 +4,8 @@ import yaml
 
 class TextDetector():
     def __init__(self, config):
-        with open(args.config, 'r') as stream:
-	    config = yaml.safe_load(stream)
+        with open(config, 'r') as stream:
+            config = yaml.safe_load(stream)
 
         download_weights(**config['weights'], quiet=True)
 
